==> haskell-fast-logger-3.2.4-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fast-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fast-logger
version:              3.2.4
visibility:           public
id:                   fast-logger-3.2.4-5jppMKK1z6HHgbKT5knJTB
key:                  fast-logger-3.2.4-5jppMKK1z6HHgbKT5knJTB
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/logger
synopsis:             A fast logging system
description:          A fast logging system for Haskell
category:             System
abi:                  eda28ed7975810848d99f1455e766669
exposed:              True
exposed-modules:
    System.Log.FastLogger System.Log.FastLogger.Date
    System.Log.FastLogger.File System.Log.FastLogger.Internal
    System.Log.FastLogger.LoggerSet System.Log.FastLogger.Types

hidden-modules:
    System.Log.FastLogger.Imports System.Log.FastLogger.FileIO
    System.Log.FastLogger.IO System.Log.FastLogger.LogStr
    System.Log.FastLogger.MultiLogger
    System.Log.FastLogger.SingleLogger System.Log.FastLogger.Write

import-dirs:          /usr/lib/ghc-9.4.8/site-local/fast-logger-3.2.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fast-logger-3.2.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fast-logger-3.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fast-logger
hs-libraries:         HSfast-logger-3.2.4-5jppMKK1z6HHgbKT5knJTB
depends:
    array-0.5.4.0 auto-update-0.1.6-BT9musxyl9BH8BdUqREn4u
    base-4.17.2.1 bytestring-0.11.5.3 directory-1.3.7.1
    easy-file-0.2.5-34Eour7k2CU2Uxn5G0MyEI filepath-1.4.2.2 stm-2.5.1.0
    text-2.0.2 unix-compat-0.7.4.1-CYGJOM1K0tFLPsAESFm1Qp
    unix-time-0.4.17-AlOVKMHoW7WQCEwFyWGac

haddock-interfaces:   /usr/share/doc/haskell-fast-logger/html/fast-logger.haddock
haddock-html:         /usr/share/doc/haskell-fast-logger/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fast-logger-3.2.4-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fast-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fast-logger
version:              3.2.4
visibility:           public
id:                   fast-logger-3.2.4-FRZKDoNfDltEmmPxC91Fmn
key:                  fast-logger-3.2.4-FRZKDoNfDltEmmPxC91Fmn
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/logger
synopsis:             A fast logging system
description:          A fast logging system for Haskell
category:             System
abi:                  2d7a961bf82c0af5d6396416de69d902
exposed:              True
exposed-modules:
    System.Log.FastLogger System.Log.FastLogger.Date
    System.Log.FastLogger.File System.Log.FastLogger.Internal
    System.Log.FastLogger.LoggerSet System.Log.FastLogger.Types

hidden-modules:
    System.Log.FastLogger.Imports System.Log.FastLogger.FileIO
    System.Log.FastLogger.IO System.Log.FastLogger.LogStr
    System.Log.FastLogger.MultiLogger
    System.Log.FastLogger.SingleLogger System.Log.FastLogger.Write

import-dirs:          /usr/lib/ghc-9.4.8/site-local/fast-logger-3.2.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fast-logger-3.2.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fast-logger-3.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fast-logger
hs-libraries:         HSfast-logger-3.2.4-FRZKDoNfDltEmmPxC91Fmn
depends:
    array-0.5.4.0 auto-update-0.1.6-Dp1M4VAJCBmHvrc1Djoexd
    base-4.17.2.1 bytestring-0.11.5.3 directory-1.3.7.1
    easy-file-0.2.5-KyazdBWKQvLDwpYzTiLg3R filepath-1.4.2.2 stm-2.5.1.0
    text-2.0.2 unix-compat-0.7.4.1-DzNkTFZTZy3DoMPfVsxmLG
    unix-time-0.4.17-4wr5211M0ug3NyI6WFhtWO

haddock-interfaces:   /usr/share/doc/haskell-fast-logger/html/fast-logger.haddock
haddock-html:         /usr/share/doc/haskell-fast-logger/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
